@@ -24,11 +24,9 @@ def topicmodelinglstm(file_name,epochs=1,no_topic=10,topic_word=5,column_name='c
     datalstm.load_cooccs(os.path.join(r"stt_lemmas_lstm.json"))
     f=8
     lr=0.015
-    print("Just before calling Doc2Topiclstm")
     modellstm = Doc2Topiclstm(datalstm, n_topics=no_topic, batch_size=1024*f, n_epochs=epochs, lr=lr, l1_doc=0.0000002, l1_word=0.000000015)
-    print("Done calling Doc2Topiclstm")
     topicwordnn=modellstm.get_topic_words(top_n=topic_word)
-    print("Done calling get_topic_words")
+    
     totalsum=0.0
     finaltopics=[]
     for i in range(no_topic):
